@@ -613,9 +613,10 @@ class TutorialGenerator:
         if (not alreadyFocused):
             try:
                 parent_table = obj.parent.queryTable()
-            except NotImplementedError:
+            except:
                 parent_table = None
-            if settings.readTableCellRow and parent_table \
+            readFullRow = self._script.utilities.shouldReadFullRow(obj)
+            if readFullRow and parent_table \
                 and not self._script.utilities.isLayoutOnly(obj.parent):
                 parent = obj.parent
                 index = self._script.utilities.cellIndex(obj)
@@ -774,7 +775,7 @@ class TutorialGenerator:
         if not settings.enableTutorialMessages:
             return []
 
-        if not obj == orca_state.locusOfFocus:
+        if not (obj and obj == orca_state.locusOfFocus):
             return []
 
         utterances = []
